package com.jasamedika.medifirst2000.service;

import java.util.List;
import java.util.Map;

import com.jasamedika.medifirst2000.vo.MasterEvaluasiJabatanVO;

public interface MasterEvaluasiJabatanService {

	Map<String, Object> saveMasterEvaluasiJabatan(MasterEvaluasiJabatanVO vo);

	Map<String, Object> saveMasterEvaluasiJabatan(List<MasterEvaluasiJabatanVO> vo);

	Map<String, Object> findEvaluasiByJabatanDanTahun(Integer tahun, Integer bulan, Integer jabatan);

	Map<String, Object> findJabatan();

	Map<String, Object> findEvaluasiByJabatan(Integer idJabatan, Integer tahun, String bulan);

	Map<String, Object> hitungPoinEvaluasi(MasterEvaluasiJabatanVO vo);

}
